@@ -1,12 +1,16 @@
-use crate::abi_example::{normalize_type_name, AbiEnumVisitor};
-use crate::hash::{Hash, Hasher};
-use log::*;
-use serde::ser::Error as SerdeError;
-use serde::ser::*;
-use serde::{Serialize, Serializer};
-use std::any::type_name;
-use std::io::Write;
-use thiserror::Error;
+use {
+    crate::{
+        abi_example::{normalize_type_name, AbiEnumVisitor},
+        hash::{Hash, Hasher},
+    },
+    log::*,
+    serde::{
+        ser::{Error as SerdeError, *},
+        Serialize, Serializer,
+    },
+    std::{any::type_name, io::Write},
+    thiserror::Error,
+};
 
 #[derive(Debug)]
 pub struct AbiDigester {
@@ -528,8 +532,7 @@ impl SerializeStructVariant for AbiDigester {
 
 #[cfg(test)]
 mod tests {
-    use std::collections::HashMap;
-    use std::sync::atomic::AtomicIsize;
+    use std::{collections::HashMap, sync::atomic::AtomicIsize};
 
     #[frozen_abi(digest = "CQiGCzsGquChkwffHjZKFqa3tCYtS3GWYRRYX7iDR38Q")]
     type TestTypeAlias = i32;
